@@ -56,7 +56,7 @@ GRL_LOG_DOMAIN_STATIC(jamendo_log_domain);
 
 /* ---- Jamendo Web API  ---- */
 
-#define JAMENDO_BASE_ENTRY "http://api.jamendo.com/get2"
+#define JAMENDO_BASE_ENTRY "https://api.jamendo.com/get2"
 #define JAMENDO_FORMAT     "xml"
 #define JAMENDO_RANGE      "n=%u&pn=%u"
 
@@ -86,8 +86,6 @@ GRL_LOG_DOMAIN_STATIC(jamendo_log_domain);
 
 /* --- Plugin information --- */
 
-#define PLUGIN_ID   JAMENDO_PLUGIN_ID
-
 #define SOURCE_ID   "grl-jamendo"
 #define SOURCE_NAME "Jamendo"
 #define SOURCE_DESC _("A source for browsing and searching Jamendo music")
@@ -216,21 +214,36 @@ grl_jamendo_plugin_init (GrlRegistry *registry,
   return TRUE;
 }
 
-GRL_PLUGIN_REGISTER (grl_jamendo_plugin_init,
-                     NULL,
-                     PLUGIN_ID);
+GRL_PLUGIN_DEFINE (GRL_MAJOR,
+                   GRL_MINOR,
+                   JAMENDO_PLUGIN_ID,
+                   "Jamendo",
+                   "A plugin for browsing and searching Jamendo videos",
+                   "Igalia S.L.",
+                   VERSION,
+                   "LGPL",
+                   "http://www.igalia.com",
+                   grl_jamendo_plugin_init,
+                   NULL,
+                   NULL);
 
 /* ================== Jamendo GObject ================ */
 
 static GrlJamendoSource *
 grl_jamendo_source_new (void)
 {
+  const char *tags[] = {
+    "net:internet",
+    NULL
+  };
+
   GRL_TRACE();
   return g_object_new (GRL_JAMENDO_SOURCE_TYPE,
 		       "source-id", SOURCE_ID,
 		       "source-name", SOURCE_NAME,
 		       "source-desc", SOURCE_DESC,
-		       "supported-media", GRL_MEDIA_TYPE_AUDIO,
+		       "supported-media", GRL_SUPPORTED_MEDIA_AUDIO,
+		       "source-tags", tags,
 		       NULL);
 }
 
@@ -529,8 +542,7 @@ update_media_from_entry (GrlMedia *media, const Entry *entry)
     }
 
     if (entry->album_genre) {
-      grl_media_audio_set_genre (GRL_MEDIA_AUDIO (media),
-                                 entry->album_genre);
+      grl_media_set_genre (media, entry->album_genre);
     }
 
     if (entry->track_url) {
@@ -573,7 +585,7 @@ xml_parse_entries_idle (gpointer user_data)
     if (entry->category == JAMENDO_TRACK_CAT) {
       media = grl_media_audio_new ();
     } else {
-      media = grl_media_box_new ();
+      media = grl_media_container_new ();
     }
 
     update_media_from_entry (media, entry);
@@ -759,7 +771,7 @@ static void
 update_media_from_root (GrlMedia *media)
 {
   grl_media_set_title (media, JAMENDO_ROOT_NAME);
-  grl_media_box_set_childcount (GRL_MEDIA_BOX (media), 3);
+  grl_media_set_childcount (media, 3);
 }
 
 static void
@@ -793,7 +805,7 @@ update_media_from_feeds (GrlMedia *media)
   };
 
   update_media_from_entry (media, &entry);
-  grl_media_box_set_childcount (GRL_MEDIA_BOX (media), G_N_ELEMENTS(feeds));
+  grl_media_set_childcount (media, G_N_ELEMENTS(feeds));
 }
 
 static void
@@ -814,7 +826,7 @@ send_toplevel_categories (GrlSourceBrowseSpec *bs)
   remaining = MIN (count, 3 - skip);
 
   while (remaining > 0) {
-    media = grl_media_box_new ();
+    media = grl_media_container_new ();
     switch (skip) {
     case 0:
       update_media_from_artists (media);
@@ -862,7 +874,7 @@ send_feeds (GrlSourceBrowseSpec *bs)
     for (i = skip; remaining > 0 && i < G_N_ELEMENTS (feeds); i++) {
       GrlMedia *media;
 
-      media = grl_media_box_new ();
+      media = grl_media_container_new ();
       update_media_from_feed (media, i);
       remaining--;
       bs->callback (bs->source,
@@ -963,7 +975,7 @@ grl_jamendo_source_resolve (GrlSource *source,
                          GRL_METADATA_KEY_ID)) {
     /* Get info from root */
     if (!rs->media) {
-      rs->media = grl_media_box_new ();
+      rs->media = grl_media_container_new ();
     }
     update_media_from_root (rs->media);
   } else {
