@@ -280,7 +280,7 @@ grl_util_add_table_to_media (lua_State *L,
 
     case G_TYPE_FLOAT:
       if (lua_isnumber (L, -1))
-        grl_data_add_float (GRL_DATA (media), key_id, lua_tointeger (L, -1));
+        grl_data_add_float (GRL_DATA (media), key_id, lua_tonumber (L, -1));
       break;
 
     case G_TYPE_STRING:
@@ -315,8 +315,8 @@ grl_util_build_media (lua_State *L,
     if (lua_isstring (L, -1)) {
       const gchar *media_type = lua_tostring (L, -1);
 
-      if (g_strcmp0 (media_type, "box") == 0)
-        media = grl_media_box_new ();
+      if (g_strcmp0 (media_type, "container") == 0)
+        media = grl_media_container_new ();
       else if (g_strcmp0 (media_type, "image") == 0)
         media = grl_media_image_new ();
       else if (g_strcmp0 (media_type, "audio") == 0)
@@ -502,7 +502,7 @@ grl_util_fetch_done (GObject *source_object,
   } else {
     lua_newtable (L);
     for (i = 0; i < fo->num_urls; i++) {
-      lua_pushnumber (L, i + 1);
+      lua_pushinteger (L, i + 1);
       lua_pushlstring (L, fo->results[i], strlen (fo->results[i]));
       lua_settable (L, -3);
     }
@@ -639,7 +639,7 @@ grl_util_unzip_done (GObject *source_object,
 
   lua_newtable (L);
   for (i = 0; results[i] != NULL; i++) {
-    lua_pushnumber (L, i + 1);
+    lua_pushinteger (L, i + 1);
     lua_pushlstring (L, results[i], strlen (results[i]));
     lua_settable (L, -3);
   }
@@ -678,7 +678,7 @@ net_wc_new_with_options(lua_State *L,
 
       } else if (g_strcmp0 (key, "cache-size") == 0 ||
                  g_strcmp0 (key, "cache_size") == 0) {
-        guint size = lua_tonumber (L, -1);
+        guint size = lua_tointeger (L, -1);
         grl_net_wc_set_cache_size (wc, size);
 
       } else if (g_strcmp0 (key, "cache") == 0) {
@@ -686,11 +686,11 @@ net_wc_new_with_options(lua_State *L,
         grl_net_wc_set_cache (wc, use_cache);
 
       } else if (g_strcmp0 (key, "throttling") == 0) {
-        guint throttling = lua_tonumber (L, -1);
+        guint throttling = lua_tointeger (L, -1);
         grl_net_wc_set_throttling (wc, throttling);
 
       } else if (g_strcmp0 (key, "loglevel") == 0) {
-        guint level = lua_tonumber (L, -1);
+        guint level = lua_tointeger (L, -1);
         grl_net_wc_set_log_level (wc, level);
 
       } else {
@@ -750,21 +750,21 @@ grl_l_operation_get_options (lua_State *L)
   if (g_strcmp0 (option, "count") == 0) {
     gint count = grl_operation_options_get_count (os->options);
 
-    lua_pushnumber (L, count);
+    lua_pushinteger (L, count);
     return 1;
   }
 
   if (g_strcmp0 (option, "skip") == 0) {
     guint skip = grl_operation_options_get_skip (os->options);
 
-    lua_pushnumber (L, skip);
+    lua_pushinteger (L, skip);
     return 1;
   }
 
   if (g_strcmp0 (option, "flags") == 0) {
     GrlResolutionFlags flags = grl_operation_options_get_resolution_flags (os->options);
 
-    lua_pushnumber (L, (gint) flags);
+    lua_pushinteger (L, (gint) flags);
     return 1;
   }
 
@@ -781,7 +781,7 @@ grl_l_operation_get_options (lua_State *L)
     value = grl_operation_options_get_key_filter (os->options, key);
     switch (grl_registry_lookup_metadata_key_type (registry, key)) {
     case G_TYPE_INT:
-      (value) ? (void) lua_pushnumber (L, g_value_get_int (value)) : lua_pushnil (L);
+      (value) ? (void) lua_pushinteger (L, g_value_get_int (value)) : lua_pushnil (L);
       break;
 
     case G_TYPE_FLOAT:
@@ -818,8 +818,8 @@ grl_l_operation_get_options (lua_State *L)
       grl_operation_options_get_key_range_filter (os->options, key, &min, &max);
       switch (grl_registry_lookup_metadata_key_type (registry, key)) {
       case G_TYPE_INT:
-        (min) ? (void) lua_pushnumber (L, g_value_get_int (min)) : lua_pushnil (L);
-        (max) ? (void) lua_pushnumber (L, g_value_get_int (max)) : lua_pushnil (L);
+        (min) ? (void) lua_pushinteger (L, g_value_get_int (min)) : lua_pushnil (L);
+        (max) ? (void) lua_pushinteger (L, g_value_get_int (max)) : lua_pushnil (L);
         break;
 
       case G_TYPE_FLOAT:
@@ -841,7 +841,7 @@ grl_l_operation_get_options (lua_State *L)
   }
 
   if (g_strcmp0 (option, "operation-id") == 0) {
-    lua_pushnumber (L, (gint) os->operation_id);
+    lua_pushinteger (L, (gint) os->operation_id);
     return 1;
   }
 
@@ -1126,7 +1126,7 @@ grl_l_fetch (lua_State *L)
 * grl.callback
 *
 * @media: (table) The media content to be returned.
-* @count: (number) Number of media remaining to the application.
+* @count: (integer) Number of media remaining to the application.
 * @return: Nothing;
 */
 static gint
@@ -1150,7 +1150,7 @@ grl_l_callback (lua_State *L)
   media = (os->op_type == LUA_RESOLVE) ? os->media : NULL;
   if (nparam > 0) {
     media = grl_util_build_media (L, media);
-    count = (lua_isnumber (L, 2)) ? lua_tonumber (L, 2) : 0;
+    count = (lua_isinteger (L, 2)) ? lua_tointeger (L, 2) : 0;
   }
 
   switch (os->op_type) {
