@@ -148,8 +148,6 @@ GRL_LOG_DOMAIN_STATIC(podcasts_log_domain);
 
 /* --- Plugin information --- */
 
-#define PLUGIN_ID   PODCASTS_PLUGIN_ID
-
 #define SOURCE_ID   "grl-podcasts"
 #define SOURCE_NAME "Podcasts"
 #define SOURCE_DESC _("A source for browsing podcasts")
@@ -317,9 +315,18 @@ grl_podcasts_plugin_init (GrlRegistry *registry,
   return TRUE;
 }
 
-GRL_PLUGIN_REGISTER (grl_podcasts_plugin_init,
-                     NULL,
-                     PLUGIN_ID);
+GRL_PLUGIN_DEFINE (GRL_MAJOR,
+                   GRL_MINOR,
+                   PODCASTS_PLUGIN_ID,
+                   "Podcasts",
+                   "A plugin for browsing podcasts",
+                   "Igalia S.L.",
+                   VERSION,
+                   "LGPL",
+                   "http://www.igalia.com",
+                   grl_podcasts_plugin_init,
+                   NULL,
+                   NULL);
 
 /* ================== Podcasts GObject ================ */
 
@@ -611,13 +618,13 @@ build_media (GrlMedia *content,
 
   if (is_podcast) {
     if (!media) {
-      media = GRL_MEDIA (grl_media_box_new ());
+      media = grl_media_container_new ();
     }
 
     grl_media_set_id (media, id);
     if (desc)
       grl_media_set_description (media, desc);
-    grl_media_box_set_childcount (GRL_MEDIA_BOX (media), childcount);
+    grl_media_set_childcount (media, childcount);
   } else {
     if (!media) {
       if (mime_is_audio (mime)) {
@@ -1202,7 +1209,7 @@ parse_entry_idle (gpointer user_data)
 		       NULL);
     /* Notify about changes */
     if (GRL_PODCASTS_SOURCE (osp->os->source)->priv->notify_changes) {
-      media = grl_media_box_new ();
+      media = grl_media_container_new ();
       grl_media_set_id (media, osp->os->media_id);
       grl_source_notify_change (GRL_SOURCE (osp->os->source),
                                 media,
@@ -1314,7 +1321,7 @@ parse_feed (OperationSpec *os, const gchar *str, GError **error)
 
   if (stream_count <= 0) {
     if (GRL_PODCASTS_SOURCE (os->source)->priv->notify_changes) {
-      podcast = grl_media_box_new ();
+      podcast = grl_media_container_new ();
       grl_media_set_id (podcast, os->media_id);
       grl_source_notify_change (GRL_SOURCE (os->source),
                                 podcast,
@@ -1794,7 +1801,7 @@ grl_podcasts_source_store (GrlSource *source, GrlSourceStoreSpec *ss)
 
   keylist = grl_data_get_keys (GRL_DATA (ss->media));
 
-  if (GRL_IS_MEDIA_BOX (ss->media)) {
+  if (grl_media_is_container (ss->media)) {
     error = g_error_new_literal (GRL_CORE_ERROR,
                                  GRL_CORE_ERROR_STORE_FAILED,
                                  _("Cannot create containers. Only feeds are accepted"));
